/*
 * Copyright (c) 2015 Meltytech, LLC
 * Author: Amy Dennedy
 *
 * Modified by Paul 05 April 2019
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtQuick.Controls 1.1
import QtQuick.Layouts 1.1
import Shotcut.Controls 1.0

Item {
    
    property string glitchFreq: '0'
    property string blockH: '1'
    property string shiftInt: '2'
    property string colorInt: '3'
    
    property double glitchFreqDefault: 0.500
    property double blockHDefault: 0.500
    property double shiftIntDefault: 0.500
    property double colorIntDefault: 0.000
	
	property real maxFilterPercent: 100.0
    property real maxUserPercent: 100.0
    property real defaultValue: 2.5 / maxFilterPercent
    
    property var defaultParameters: [glitchFreq, blockH, shiftInt, colorInt]
    
    width: 350
    height: 450
    
    Component.onCompleted: {
        if (filter.isNew) {
            filter.set(glitchFreq, glitchFreqDefault)
            filter.set(blockH, blockHDefault)
            filter.set(shiftInt, shiftIntDefault)
            filter.set(colorInt, colorIntDefault)
            filter.savePreset(preset.defaultParameters)
        }
        glitchFreqSlider.value = filter.getDouble(glitchFreq) * maxFilterPercent
        blockHSlider.value = filter.getDouble(blockH) * maxFilterPercent
        shiftIntSlider.value = filter.getDouble(shiftInt) * maxFilterPercent
        colorIntSlider.value = filter.getDouble(colorInt) * maxFilterPercent
    }

    function setControls() {
        glitchFreqSlider.value = filter.getDouble(glitchFreq) * maxFilterPercent
        blockHSlider.value = filter.getDouble(blockH) * maxFilterPercent
        shiftIntSlider.value = filter.getDouble(shiftInt) * maxFilterPercent
        colorIntSlider.value = filter.getDouble(colorInt) * maxFilterPercent
    }

    GridLayout {
        anchors.fill: parent
        anchors.margins: 8
        columns: 3

        Label {
            text: qsTr('Preset')
            Layout.alignment: Qt.AlignRight
        }
        Preset {
            id: preset
            parameters: [glitchFreq, blockH, shiftInt, colorInt]
            Layout.columnSpan: 2
            onPresetSelected: setControls()
        }

        Label {
            text: qsTr('Glitch Frequency')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: glitchFreqSlider
            minimumValue: 0.1
            maximumValue: maxUserPercent
			stepSize: 0.1
            decimals: 1
			suffix: ' %'
            //value: filter.getDouble(glitchFreq)
            onValueChanged: filter.set(glitchFreq, value / maxFilterPercent)
        }
        UndoButton {
            onClicked: glitchFreqSlider.value = glitchFreqDefault * maxFilterPercent
        }

        Label {
            text: qsTr('Block Height')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: blockHSlider
            minimumValue: 0.1
            maximumValue: maxUserPercent
			stepSize: 0.1
            decimals: 1
			suffix: ' %'
            //value: filter.getDouble(blockH)
            onValueChanged: filter.set(blockH, value / maxFilterPercent)
            }
        UndoButton {
            onClicked: blockHSlider.value = blockHDefault * maxFilterPercent
        }

        Label {
            text: qsTr('Shift Intensity')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: shiftIntSlider
            minimumValue: 0.1
            maximumValue: maxUserPercent
			stepSize: 0.1
            decimals: 1
			suffix: ' %'
            //value: filter.getDouble(shiftInt)
            onValueChanged: filter.set(shiftInt, value / maxFilterPercent)
        }
        UndoButton {
            onClicked: shiftIntSlider.value = shiftIntDefault * maxFilterPercent
        }

        Label {
            text: qsTr('Color Intensity')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: colorIntSlider
            minimumValue: 0.1
            maximumValue: maxUserPercent
			stepSize: 0.1
            decimals: 1
			suffix: ' %'
            //value: filter.getDouble(colorInt)
            onValueChanged: filter.set(colorInt, value / maxFilterPercent)
        }
        UndoButton {
            onClicked: colorIntSlider.value = colorIntDefault * maxFilterPercent
        }

        Item {
            Layout.fillHeight: true;
        }
    }
    // Connections {
       // target: producer
      //  onPositionChanged: setControls()
    // }
  }
